==> huaweicloudsdkkafka-3.0.46-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_instance_user_req.py <==
# coding: utf-8

import pprint
import re

import six





class CreateInstanceUserReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_name': 'str',
        'user_passwd': 'str'
    }

    attribute_map = {
        'user_name': 'user_name',
        'user_passwd': 'user_passwd'
    }

    def __init__(self, user_name=None, user_passwd=None):
        """CreateInstanceUserReq - a model defined in huaweicloud sdk"""
        
        

        self._user_name = None
        self._user_passwd = None
        self.discriminator = None

        if user_name is not None:
            self.user_name = user_name
        if user_passwd is not None:
            self.user_passwd = user_passwd

    @property
    def user_name(self):
        """Gets the user_name of this CreateInstanceUserReq.

        用户名称。

        :return: The user_name of this CreateInstanceUserReq.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this CreateInstanceUserReq.

        用户名称。

        :param user_name: The user_name of this CreateInstanceUserReq.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_passwd(self):
        """Gets the user_passwd of this CreateInstanceUserReq.

        用户密码。 密码不能和用户名相同。 复杂度要求： - 输入长度为8到32位的字符串。 - 必须包含如下四种字符中的两种组合：   - 小写字母   - 大写字母   - 数字   - 特殊字符包括（`~!@#$%^&*()-_=+\\|[{}]:'\",<.>/?）

        :return: The user_passwd of this CreateInstanceUserReq.
        :rtype: str
        """
        return self._user_passwd

    @user_passwd.setter
    def user_passwd(self, user_passwd):
        """Sets the user_passwd of this CreateInstanceUserReq.

        用户密码。 密码不能和用户名相同。 复杂度要求： - 输入长度为8到32位的字符串。 - 必须包含如下四种字符中的两种组合：   - 小写字母   - 大写字母   - 数字   - 特殊字符包括（`~!@#$%^&*()-_=+\\|[{}]:'\",<.>/?）

        :param user_passwd: The user_passwd of this CreateInstanceUserReq.
        :type: str
        """
        self._user_passwd = user_passwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceUserReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.0.51-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_instance_user_req.py <==
# coding: utf-8

import re
import six





class CreateInstanceUserReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_name': 'str',
        'user_passwd': 'str'
    }

    attribute_map = {
        'user_name': 'user_name',
        'user_passwd': 'user_passwd'
    }

    def __init__(self, user_name=None, user_passwd=None):
        """CreateInstanceUserReq - a model defined in huaweicloud sdk"""
        
        

        self._user_name = None
        self._user_passwd = None
        self.discriminator = None

        if user_name is not None:
            self.user_name = user_name
        if user_passwd is not None:
            self.user_passwd = user_passwd

    @property
    def user_name(self):
        """Gets the user_name of this CreateInstanceUserReq.

        用户名称。

        :return: The user_name of this CreateInstanceUserReq.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this CreateInstanceUserReq.

        用户名称。

        :param user_name: The user_name of this CreateInstanceUserReq.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_passwd(self):
        """Gets the user_passwd of this CreateInstanceUserReq.

        用户密码。 密码不能和用户名相同。 复杂度要求： - 输入长度为8到32位的字符串。 - 必须包含如下四种字符中的两种组合：   - 小写字母   - 大写字母   - 数字   - 特殊字符包括（`~!@#$%^&*()-_=+\\|[{}]:'\",<.>/?）

        :return: The user_passwd of this CreateInstanceUserReq.
        :rtype: str
        """
        return self._user_passwd

    @user_passwd.setter
    def user_passwd(self, user_passwd):
        """Sets the user_passwd of this CreateInstanceUserReq.

        用户密码。 密码不能和用户名相同。 复杂度要求： - 输入长度为8到32位的字符串。 - 必须包含如下四种字符中的两种组合：   - 小写字母   - 大写字母   - 数字   - 特殊字符包括（`~!@#$%^&*()-_=+\\|[{}]:'\",<.>/?）

        :param user_passwd: The user_passwd of this CreateInstanceUserReq.
        :type: str
        """
        self._user_passwd = user_passwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceUserReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
